@@ -6,6 +6,7 @@ import argparse
 import shutil
 from acm import ACMClient, DEFAULT_GROUP_NAME
 
+DEFAULT_PORT = 8080
 CMD = set(["bind", "set", "use"])
 CONF = os.path.join(os.getenv("HOME"), ".acm.json")
 
@@ -101,6 +102,10 @@ def bind(args):
     config = read_config()
     ep = args.endpoint
     tls = args.tls
+
+    if ":" not in ep and not tls:
+        ep = "%s:%s" % (ep, DEFAULT_PORT)
+
     if ep not in config["endpoints"]:
         config["endpoints"][ep] = {
             "tls": tls,
@@ -127,6 +132,10 @@ def bind(args):
 
     write_config(config)
 
+    if args.namespace:
+        add(args)
+        use(args)
+
 
 def add(args):
     config = read_config()
@@ -462,16 +471,27 @@ def arg_parse():
 
     # bind
     parser_bind = subparsers.add_parser("bind", help="bind to an ACM endpoint",
-                                        description="Bind to an ACM endpoint, use [acm.aliyun.com:8080] as default.")
+                                        description="Bind to an ACM endpoint, use [acm.aliyun.com:8080] as default, "
+                                                    "a namespace can be added at the same time.",
+                                        epilog="Example: acm bind acm.aliyun.com -u "
+                                               "ea61357b-d417-460c-92e4-032677dd8153 -s 'GLff***xcao=' "
+                                               "-a 654b43******e9750 -n foo")
     parser_bind.add_argument("endpoint", help="ACM endpoint to bind.")
     parser_bind.add_argument("--tls", action="store_true", default=False, help="to use tls connection.")
+
+    parser_bind.add_argument("-u", dest="namespace", help='namespace to add.')
+    parser_bind.add_argument("-a", dest="ak", default=None, help='AccessKey of this namespace.')
+    parser_bind.add_argument("-s", dest="sk", help='SecretKey of this namespace.')
+    parser_bind.add_argument("-n", dest="alias", help="alias of the endpoint.")
     parser_bind.set_defaults(func=bind)
 
     # add
     parser_add = subparsers.add_parser("add", help="add a namespace",
                                        description="Add a namespace to current endpoint, "
-                                                   "update if namespace is already added.")
-    parser_add.add_argument("namespace", help='namespace to add.')
+                                                   "update if namespace is already added.",
+                                       epilog="Example: acm add ea61357b-d417-460c-92e4-032677dd8153 "
+                                              "-s 'GLff***xcao=' -a 654b43******e9750 -n foo")
+    parser_add.add_argument("namespace", default=None, help='namespace to add.')
     parser_add.add_argument("-a", dest="ak", default=None, help='AccessKey of this namespace.')
     parser_add.add_argument("-s", dest="sk", help='SecretKey of this namespace.')
     parser_add.add_argument("-n", dest="alias", help="alias of the endpoint.")
@@ -480,7 +500,8 @@ def arg_parse():
     # use
     parser_use = subparsers.add_parser("use", help="switch to a namespace",
                                        description="Switch to a namespace of current endpoint, "
-                                                   "if namespace is absent, add one.")
+                                                   "if namespace is absent, add one.",
+                                       epilog="Example: acm use foo")
     parser_use.add_argument("namespace", help='namespace or alias to use.')
     parser_use.add_argument("-a", dest="ak", default=None, help='AccessKey of this namespace.')
     parser_use.add_argument("-s", dest="sk", help='SecretKey of this namespace.')
@@ -506,7 +527,8 @@ def arg_parse():
 
     # pull
     parser_pull = subparsers.add_parser("pull", help="get one config content",
-                                        description="Get one config content from ACM server and save to local file.")
+                                        description="Get one config content from ACM server and save to local file.",
+                                        epilog="Example: acm pull group/dataId")
     parser_pull.add_argument("data_id", help='the dataId to pull, use group"/"dataId to specify group, '
                                              'if group is specified, file will be store under an subdir of group name.')
     parser_pull.add_argument("-f", dest="file", default=None, help="file to store the content, create one if absent.")
@@ -516,7 +538,8 @@ def arg_parse():
 
     # push
     parser_push = subparsers.add_parser("push", help="push one config",
-                                        description="Push one config with content of local file to ACM server.")
+                                        description="Push one config with content of local file to ACM server.",
+                                        epilog="Example: acm push dir/file")
     parser_push.add_argument("file", help="file to push, filename is use as dataId by default, "
                                           "if parent dir is attached, it will be use as group.")
     parser_push.add_argument("-d", dest="data_id", default=None, help='dataId to store the content, '
